@@ -1,9 +1,9 @@
 #
-# $Id: Factor.pm,v 0.01 2004/01/06 12:19:58 sts Exp $
+# $Id: Factor.pm,v 0.02 2004/01/06 13:59:18 sts Exp $
 
 package Math::Factor;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use integer;
 use strict;
@@ -31,27 +31,39 @@ sub croak {
 
 =head1 NAME
 
-Math::Factor - factorises integers and calculates matching multiplications.
+Math::Factor - factorise integers and calculate matching multiplications.
 
 =head1 SYNOPSIS
 
-    use Math::Factor q/:all/;
+ use Math::Factor q/:all/;
+
+ @numbers = (9);
+
+ # data manipulation
+ %factors = factor (\@numbers);
+ %matches = match (\%factors);
+
+ # output
+ show_factor (\%factors);
+ show_match (\%matches);
 
 =head1 DESCRIPTION
 
-C<Math::Factor> factorises integers and calculates matching multiplications.
+see above.
 
 =head1 FUNCTIONS
 
 =head2 factor
 
-=cut
+Factorises numbers.
 
-#
-# factor (\@numbers)
-#
-# Number factorisation.
-#
+ %factors = factor (\@numbers);
+
+Each number within @numbers will be entirely factorised and its factors will be
+saved within %factors, accessible by the number itself e.g  the factors of 9 may
+be accessed by @{$factors{9}}.
+
+=cut
 
 sub factor {
     my $number_ref = $_[0];
@@ -72,13 +84,17 @@ sub factor {
 
 =head2 match
 
-=cut
+Evaluates matching multiplications.
 
-#
-# match (\%factors)
-#
-# Evaluates matching multiplications.
-#
+ %matches = match (\%factors);
+
+The factors of each number within %factors will be multplicated against
+each other and results the equal the number itself, will be saved to %matches.
+The matches are accessible through the according numbers e.g. the first two numbers
+that matched 9, may be accessed by $matches{9}[0][0] and $matches{9}[0][1], the second
+ones by $matches{9}[1][0] and $matches{9}[1][1], and so on.
+
+=cut
 
 sub match {
     my $number_ref = $_[0];
@@ -107,13 +123,15 @@ sub match {
 
 =head2 show_factor
 
-=cut
+Outputs all numbers and their according factors to STDOUT.
 
-#
-# show_factor (\%factors)
-#
-# Outputs factors.
-#
+ show_factor (\%factors);
+
+   9
+   -
+   1    3    9
+
+=cut
 
 sub show_factor {
     my $number_ref = $_[0];
@@ -141,13 +159,16 @@ EOT
 
 =head2 show_match
 
-=cut
+Outputs all numbers and their according matching multiplications to STDOUT.
 
-#
-# show_match (\%match)
-#
-# Outputs matching multplications.
-#
+ show_match (\%matches);
+
+   9
+   -
+   1 * 9
+   3 * 3
+
+=cut
 
 sub show_match {
     my $number_ref = $_[0];
@@ -179,11 +200,15 @@ EOT
 1;
 __END__
 
+=head2 LIMITATIONS
+
+Evaluating ranges of factors or multiplication matches is unimplemented aswell as iterating factors or multiplication matches.
+
 =head2 EXPORT
 
 C<factor(), match(), show_factor(), show_match()> upon request.
 
-=head2 TAGS
+B<TAGS>
 
 C<:all - *()>
 
